@@ -1,3 +1,5 @@
+#ifdef _WIN32
+
 /* mz_os_win32.c -- System functions for Windows
    part of the minizip-ng project
 
@@ -8,8 +10,6 @@
    See the accompanying LICENSE file for the full text of the license.
 */
 
-#ifdef WIN32
-
 #include "mz.h"
 #include "mz_os.h"
 #include "mz_strm_os.h"
@@ -30,10 +30,10 @@
 /***************************************************************************/
 
 typedef struct DIR_int_s {
-    void            *find_handle;
+    void *find_handle;
     WIN32_FIND_DATAW find_data;
-    struct dirent    entry;
-    uint8_t          end;
+    struct dirent entry;
+    uint8_t end;
 } DIR_int;
 
 /***************************************************************************/
@@ -236,8 +236,7 @@ static void mz_os_unix_to_file_time(time_t unix_time, FILETIME *file_time) {
 }
 
 int32_t mz_os_get_file_date(const char *path, time_t *modified_date, time_t *accessed_date, time_t *creation_date) {
-    WIN32_FIND_DATAW ff32;
-    HANDLE handle = NULL;
+    WIN32_FILE_ATTRIBUTE_DATA wfad;
     wchar_t *path_wide = NULL;
     int32_t err = MZ_INTERNAL_ERROR;
 
@@ -247,21 +246,19 @@ int32_t mz_os_get_file_date(const char *path, time_t *modified_date, time_t *acc
     if (!path_wide)
         return MZ_PARAM_ERROR;
 
-    handle = FindFirstFileW(path_wide, &ff32);
-    free(path_wide);
-
-    if (handle != INVALID_HANDLE_VALUE) {
+    if (GetFileAttributesExW(path_wide, GetFileExInfoStandard, &wfad)) {
         if (modified_date)
-            mz_os_file_to_unix_time(ff32.ftLastWriteTime, modified_date);
+            mz_os_file_to_unix_time(wfad.ftLastWriteTime, modified_date);
         if (accessed_date)
-            mz_os_file_to_unix_time(ff32.ftLastAccessTime, accessed_date);
+            mz_os_file_to_unix_time(wfad.ftLastAccessTime, accessed_date);
         if (creation_date)
-            mz_os_file_to_unix_time(ff32.ftCreationTime, creation_date);
+            mz_os_file_to_unix_time(wfad.ftCreationTime, creation_date);
 
-        FindClose(handle);
         err = MZ_OK;
     }
 
+    free(path_wide);
+
     return err;
 }
 
@@ -403,7 +400,7 @@ DIR *mz_os_open_dir(const char *path) {
     return (DIR *)dir_int;
 }
 
-struct dirent* mz_os_read_dir(DIR *dir) {
+struct dirent *mz_os_read_dir(DIR *dir) {
     DIR_int *dir_int;
 
     if (!dir)
@@ -413,8 +410,8 @@ struct dirent* mz_os_read_dir(DIR *dir) {
     if (dir_int->end)
         return NULL;
 
-    WideCharToMultiByte(CP_UTF8, 0, dir_int->find_data.cFileName, -1,
-        dir_int->entry.d_name, sizeof(dir_int->entry.d_name), NULL, NULL);
+    WideCharToMultiByte(CP_UTF8, 0, dir_int->find_data.cFileName, -1, dir_int->entry.d_name,
+                        sizeof(dir_int->entry.d_name), NULL, NULL);
 
     if (FindNextFileW(dir_int->find_handle, &dir_int->find_data) == 0) {
         if (GetLastError() != ERROR_NO_MORE_FILES)
@@ -439,6 +436,10 @@ int32_t mz_os_close_dir(DIR *dir) {
     return MZ_OK;
 }
 
+int32_t mz_os_is_dir_separator(const char c) {
+    return c == '\\' || c == '/';
+}
+
 int32_t mz_os_is_dir(const char *path) {
     wchar_t *path_wide = NULL;
     uint32_t attribs = 0;
@@ -482,7 +483,7 @@ int32_t mz_os_is_symlink(const char *path) {
 }
 
 int32_t mz_os_make_symlink(const char *path, const char *target_path) {
-    typedef BOOLEAN (WINAPI *LPCREATESYMBOLICLINKW)(LPCWSTR, LPCWSTR, DWORD);
+    typedef BOOLEAN(WINAPI * LPCREATESYMBOLICLINKW)(LPCWSTR, LPCWSTR, DWORD);
     MEMORY_BASIC_INFORMATION mbi;
     LPCREATESYMBOLICLINKW create_symbolic_link_w = NULL;
     HMODULE kernel32_mod = NULL;
@@ -494,7 +495,7 @@ int32_t mz_os_make_symlink(const char *path, const char *target_path) {
     if (!path)
         return MZ_PARAM_ERROR;
 
-    // Use VirtualQuery instead of GetModuleHandleW for UWP
+    /* Use VirtualQuery instead of GetModuleHandleW for UWP */
     memset(&mbi, 0, sizeof(mbi));
     VirtualQuery(VirtualQuery, &mbi, sizeof(mbi));
     kernel32_mod = (HMODULE)mbi.AllocationBase;
@@ -532,7 +533,7 @@ int32_t mz_os_make_symlink(const char *path, const char *target_path) {
 
 int32_t mz_os_read_symlink(const char *path, char *target_path, int32_t max_target_path) {
     typedef struct _REPARSE_DATA_BUFFER {
-        ULONG  ReparseTag;
+        ULONG ReparseTag;
         USHORT ReparseDataLength;
         USHORT Reserved;
         union {
@@ -541,18 +542,18 @@ int32_t mz_os_read_symlink(const char *path, char *target_path, int32_t max_targ
                 USHORT SubstituteNameLength;
                 USHORT PrintNameOffset;
                 USHORT PrintNameLength;
-                ULONG  Flags;
-                WCHAR  PathBuffer[1];
+                ULONG Flags;
+                WCHAR PathBuffer[1];
             } SymbolicLinkReparseBuffer;
             struct {
                 USHORT SubstituteNameOffset;
                 USHORT SubstituteNameLength;
                 USHORT PrintNameOffset;
                 USHORT PrintNameLength;
-                WCHAR  PathBuffer[1];
+                WCHAR PathBuffer[1];
             } MountPointReparseBuffer;
             struct {
-                UCHAR  DataBuffer[1];
+                UCHAR DataBuffer[1];
             } GenericReparseBuffer;
         };
     } REPARSE_DATA_BUFFER;
@@ -565,7 +566,7 @@ int32_t mz_os_read_symlink(const char *path, char *target_path, int32_t max_targ
     int32_t target_path_len = 0;
     int32_t target_path_idx = 0;
     int32_t err = MZ_OK;
-    char    *target_path_utf8 = NULL;
+    char *target_path_utf8 = NULL;
 
     if (!path)
         return MZ_PARAM_ERROR;
@@ -585,7 +586,7 @@ int32_t mz_os_read_symlink(const char *path, char *target_path, int32_t max_targ
     handle = CreateFile2(path_wide, FILE_READ_EA, FILE_SHARE_READ | FILE_SHARE_WRITE, OPEN_EXISTING, &extended_params);
 #else
     handle = CreateFileW(path_wide, FILE_READ_EA, FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, OPEN_EXISTING,
-        FILE_FLAG_BACKUP_SEMANTICS | FILE_FLAG_OPEN_REPARSE_POINT, NULL);
+                         FILE_FLAG_BACKUP_SEMANTICS | FILE_FLAG_OPEN_REPARSE_POINT, NULL);
 #endif
 
     if (handle == INVALID_HANDLE_VALUE) {
@@ -595,8 +596,7 @@ int32_t mz_os_read_symlink(const char *path, char *target_path, int32_t max_targ
 
     if (DeviceIoControl(handle, FSCTL_GET_REPARSE_POINT, NULL, 0, buffer, sizeof(buffer), &length, NULL) == TRUE) {
         reparse_data = (REPARSE_DATA_BUFFER *)buffer;
-        if ((IsReparseTagMicrosoft(reparse_data->ReparseTag)) &&
-            (reparse_data->ReparseTag == IO_REPARSE_TAG_SYMLINK)) {
+        if ((IsReparseTagMicrosoft(reparse_data->ReparseTag)) && (reparse_data->ReparseTag == IO_REPARSE_TAG_SYMLINK)) {
             target_path_len = max_target_path * sizeof(wchar_t);
             if (target_path_len > reparse_data->SymbolicLinkReparseBuffer.PrintNameLength)
                 target_path_len = reparse_data->SymbolicLinkReparseBuffer.PrintNameLength;
@@ -605,7 +605,7 @@ int32_t mz_os_read_symlink(const char *path, char *target_path, int32_t max_targ
             if (target_path_wide) {
                 target_path_idx = reparse_data->SymbolicLinkReparseBuffer.PrintNameOffset / sizeof(wchar_t);
                 memcpy(target_path_wide, &reparse_data->SymbolicLinkReparseBuffer.PathBuffer[target_path_idx],
-                    target_path_len);
+                       target_path_len);
 
                 target_path_wide[target_path_len / sizeof(wchar_t)] = 0;
                 target_path_utf8 = mz_os_utf8_string_create_from_unicode(target_path_wide, MZ_ENCODING_UTF8);
