@@ -22,6 +22,8 @@
 
 #include "viz/scene3d/plane.hpp"
 
+#include "data/image.hpp"
+
 #include <geometry/data/image.hpp>
 
 #include <viz/scene3d/helper/manual_object.hpp>
@@ -36,6 +38,10 @@
 #include <OGRE/OgreSceneManager.h>
 #include <OGRE/OgreSceneNode.h>
 
+#include <OgrePixelFormat.h>
+
+#include <algorithm>
+
 namespace sight::viz::scene3d
 {
 
@@ -135,8 +141,7 @@ plane::~plane()
 
 void plane::update(
     axis_t _axis,
-    const Ogre::Vector3& _spacing,
-    bool _enable_transparency
+    const Ogre::Vector3& _spacing
 )
 {
     m_axis = _axis;
@@ -220,9 +225,8 @@ void plane::update(
 
     m_plane_material->set_texture("image", m_texture->get(), filter_type);
     m_plane_material->set_vertex_uniform("u_orientation", orientation_index);
-    m_plane_material->set_fragment_uniform("u_window", m_texture->window());
     m_plane_material->set_fragment_uniform("u_orientation", orientation_index);
-    m_plane_material->set_fragment_uniform("u_enableAlpha", static_cast<int>(_enable_transparency));
+
     if(m_mask_texture)
     {
         m_plane_material->set_texture("mask", m_mask_texture->get());
@@ -238,6 +242,7 @@ void plane::update(
 
         // Create the border.
         m_border.shape = m_scene_manager->createManualObject(m_slice_plane_name + "_Border");
+        m_border.shape->setRenderQueueGroup(rq::SURFACE);
         m_border.shape->estimateVertexCount(5);
         m_border.shape->begin(m_border.material, Ogre::RenderOperation::OT_LINE_STRIP);
 
@@ -335,8 +340,13 @@ void plane::update_position()
 
 //-----------------------------------------------------------------------------
 
-void plane::set_tf_data(const viz::scene3d::transfer_function& _tf_texture)
+void plane::set_tf_data(
+    const viz::scene3d::transfer_function& _tf_texture,
+    bool _enable_transparency
+)
 {
+    m_plane_material->set_fragment_uniform("u_window", m_texture->window());
+    m_plane_material->set_fragment_uniform("u_enableAlpha", static_cast<int>(_enable_transparency));
     m_plane_material->set_texture("tfTexture", _tf_texture.get());
     m_plane_material->set_fragment_uniform("u_f3TFWindow", _tf_texture.m_window);
 }
@@ -398,13 +408,14 @@ void plane::change_slice(const std::array<float, 3>& _slices_index)
 
         // Create the border.
         m_slices_cross.shape = m_scene_manager->createManualObject(m_slice_plane_name + "_Others");
+        m_slices_cross.shape->setRenderQueueGroup(rq::SURFACE);
         m_slices_cross.shape->estimateVertexCount(4);
         m_slices_cross.shape->begin(m_slices_cross.material, Ogre::RenderOperation::OT_LINE_LIST);
 
         const auto half_width  = m_size[0] * .5F;
         const auto half_height = m_size[1] * .5F;
 
-        const auto dash_length = std::max(std::max(m_size[0], m_size[1]), m_size[2]) / 100.F;
+        const auto dash_length = std::max({m_size[0], m_size[1], m_size[2]}) / 100.F;
         using sight::viz::scene3d::helper::manual_object;
         if(m_axis == axis_t::x_axis)
         {
